==> connector-packaging-generic-3.18.0-java.zip: examples/be/ehealth/businessconnector/vsbnet/async/session/VsbNetGetGenericAsyncIntegrationTest.java <==
package be.ehealth.businessconnector.vsbnet.async.session;

import be.fgov.ehealth.technicalconnector.tests.junit.rule.SessionRule;
import org.junit.Assert;
import org.junit.Rule;
import org.junit.Test;


/**
 * @author EHP
 */
public class VsbNetGetGenericAsyncIntegrationTest {

    @Rule
    public SessionRule rule = SessionRule.withActiveSession().baseOn("/be.ehealth.businessconnector.vsbnet.test.properties").build();

    private static final String RESPONSE_FOLDER = "/examples/vsbnet/async/response/";

//    @ClassRule
//    public static TestRule sslRule = SSLVerificationRule.disable();

    @Test
    public void getCreateApplication_TC_APP1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP1.xml", true);
    }

    @Test
    public void getCreateApplication_TC_APP2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP2.xml", true);
    }

    @Test
    public void getCreateApplication_TC_APP3() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP3.xml", true);
    }

    @Test
    public void getCreateApplication_TC_APP4() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP4.xml", true);
    }

    @Test
    public void getCreateApplication_TC_APP5() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP5.xml", true);
    }

    @Test
    public void getCreateApplication_TC_APP6() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP6.xml", true);
    }

    @Test
    public void getConsultApplication_TC_CAPP1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ConsultApplication(RESPONSE_FOLDER +"EMOHMDF103ConsultApplicationResponse_TC_CAPP1.xml", true);

    }

    @Test
    public void getConsultApplication_TC_CAPP2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ConsultApplication(RESPONSE_FOLDER +"EMOHMDF103ConsultApplicationResponse_TC_CAPP2.xml", true);
    }

    @Test
    public void getReportDelivery_TC_DEL1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ReportDelivery(RESPONSE_FOLDER +"EMOHMDF105ReportDeliveryResponse_TC_DEL1.xml", true);
    }

    @Test
    public void _140_getReportDelivery_TC_DEL2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ReportDelivery(RESPONSE_FOLDER +"EMOHMDF105ReportDeliveryResponse_TC_DEL2.xml", true);
    }

    @Test
    public void getReportDelivery_TC_DEL3() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ReportDelivery(RESPONSE_FOLDER +"EMOHMDF105ReportDeliveryResponse_TC_DEL3.xml", true);
    }

    @Test
    public void getReportDelivery_TC_DEL4() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ReportDelivery(RESPONSE_FOLDER +"EMOHMDF105ReportDeliveryResponse_TC_DEL4.xml", true);
    }

    @Test
    public void getConsultSupportAndRepair_TC_CSUP1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ConsultSupportAndRepair(RESPONSE_FOLDER +"EMOHMDF104ConsultSupportAndRepairResponse_TC_CSUP1.xml", true);
    }

    @Test
    public void getConsultSupportAndRepair_TC_CSUP2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ConsultSupportAndRepair(RESPONSE_FOLDER +"EMOHMDF104ConsultSupportAndRepairResponse_TC_CSUP2.xml", true);
    }

    @Test
    public void getCreateFictionalApplicationResponse_TC_FAPP1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateFictionalApplication(RESPONSE_FOLDER +"EMOHMDF102CreateFictionalApplicationResponse_TC_FAPP1.xml", true);
    }

    @Test
    public void getCreateFictionalApplicationResponse_TC_FAPP2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateFictionalApplication(RESPONSE_FOLDER +"EMOHMDF102CreateFictionalApplicationResponse_TC_FAPP2.xml", true);
    }

    @Test
    public void getCreateFictionalApplicationResponse_TC_FAPP3() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateFictionalApplication(RESPONSE_FOLDER +"EMOHMDF102CreateFictionalApplicationResponse_TC_FAPP3.xml", true);
    }

    @Test
    public void getCreateFictionalApplicationResponse_TC_FAPP4() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateFictionalApplication(RESPONSE_FOLDER +"EMOHMDF102CreateFictionalApplicationResponse_TC_FAPP3.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES1.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES2.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES3() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES3.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES4() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES4.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES5() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES5.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES6() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionRequest_TC_PDES6.xml", false);
    }

    @Test
    public void getPushDecision_TC_PDES7() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES7.xml", true);
    }

    @Test
    public void getPushApplicationView_TC_PVIEW() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushApplicationView(RESPONSE_FOLDER +"EMOHMDF107PushApplicationViewRequest_TC_PVIEW.xml", true);
    }

    @Test
    public void getListInvoiceFileAccepted() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ListInvoiceFileAccepted(RESPONSE_FOLDER +"921000_TC02.txt", true);
    }

    @Test
    public void getListInvoiceAccepted1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ListInvoiceAccepted1(RESPONSE_FOLDER +"920098_TC02.txt", true);
    }

    @Test
    public void getListInvoiceAccepted2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ListInvoiceAccepted2(RESPONSE_FOLDER +"920900_TC02.txt", true);
    }

    @Test
    public void getListInvoiceRefused() {
        Assert.fail("not testable at the time of release 3.16.0-beta-3");
    }

    @Test
    public void getListInvoiceFileRefused() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ListInvoiceFileRefused(RESPONSE_FOLDER +"920999_TC01.txt", true);
    }

    @Test
    public void getDetermineInsurability_TC01() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_DetermineInsurability(RESPONSE_FOLDER +"WZCMHDF001DetermineInsurabilityResponse_TC_1.xml", true);
    }

    @Test
    public void getDetermineInsurability_TC02() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_DetermineInsurability(RESPONSE_FOLDER +"WZCMHDF001DetermineInsurabilityResponse_TC_2.xml", true);
    }

    @Test
    public void getDetermineInsurability_TC03() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_DetermineInsurability(RESPONSE_FOLDER +"WZCMHDF001DetermineInsurabilityResponse_TC_3.xml", true);
    }

    @Test
    public void getDetermineInsurability_TC04() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_DetermineInsurability(RESPONSE_FOLDER +"WZCMHDF001DetermineInsurabilityResponse_TC_4.xml", true);
    }
}

==> connector-packaging-generic-3.19.1-java.zip: examples/be/ehealth/businessconnector/vsbnet/async/session/VsbNetGetGenericAsyncIntegrationTest.java <==
package be.ehealth.businessconnector.vsbnet.async.session;

import be.fgov.ehealth.technicalconnector.tests.junit.rule.SessionRule;
import org.junit.Assert;
import org.junit.Ignore;
import org.junit.Rule;
import org.junit.Test;


/**
 * @author EHP
 */
public class VsbNetGetGenericAsyncIntegrationTest {

    @Rule
    public SessionRule rule = SessionRule.withActiveSession().baseOn("/be.ehealth.businessconnector.vsbnet.test.properties").build();

    private static final String RESPONSE_FOLDER = "/examples/vsbnet/async/response/";

//    @ClassRule
//    public static TestRule sslRule = SSLVerificationRule.disable();

    @Test
    public void getCreateApplication_TC_APP1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP1.xml", true);
    }

    @Test
    public void getCreateApplication_TC_APP2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP2.xml", true);
    }

    @Test
    public void getCreateApplication_TC_APP3() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP3.xml", true);
    }

    @Test
    public void getCreateApplication_TC_APP4() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP4.xml", true);
    }

    @Test
    public void getCreateApplication_TC_APP5() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP5.xml", true);
    }

    @Test
    public void getCreateApplication_TC_APP6() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateApplication(RESPONSE_FOLDER +"EMOHMDF101CreateApplicationResponse_TC_APP6.xml", true);
    }

    @Test
    public void getConsultApplication_TC_CAPP1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ConsultApplication(RESPONSE_FOLDER +"EMOHMDF103ConsultApplicationResponse_TC_CAPP1.xml", true);

    }

    @Test
    public void getConsultApplication_TC_CAPP2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ConsultApplication(RESPONSE_FOLDER +"EMOHMDF103ConsultApplicationResponse_TC_CAPP2.xml", true);
    }

    @Test
    public void getReportDelivery_TC_DEL1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ReportDelivery(RESPONSE_FOLDER +"EMOHMDF105ReportDeliveryResponse_TC_DEL1.xml", true);
    }

    @Test
    public void _140_getReportDelivery_TC_DEL2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ReportDelivery(RESPONSE_FOLDER +"EMOHMDF105ReportDeliveryResponse_TC_DEL2.xml", true);
    }

    @Test
    public void getReportDelivery_TC_DEL3() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ReportDelivery(RESPONSE_FOLDER +"EMOHMDF105ReportDeliveryResponse_TC_DEL3.xml", true);
    }

    @Test
    public void getReportDelivery_TC_DEL4() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ReportDelivery(RESPONSE_FOLDER +"EMOHMDF105ReportDeliveryResponse_TC_DEL4.xml", true);
    }

    @Test
    public void getConsultSupportAndRepair_TC_CSUP1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ConsultSupportAndRepair(RESPONSE_FOLDER +"EMOHMDF104ConsultSupportAndRepairResponse_TC_CSUP1.xml", true);
    }

    @Test
    public void getConsultSupportAndRepair_TC_CSUP2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ConsultSupportAndRepair(RESPONSE_FOLDER +"EMOHMDF104ConsultSupportAndRepairResponse_TC_CSUP2.xml", true);
    }

    @Test
    @Ignore("test file not found in resources")
    public void getCreateFictionalApplicationResponse_TC_FAPP1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateFictionalApplication(RESPONSE_FOLDER +"EMOHMDF102CreateFictionalApplicationResponse_TC_FAPP1.xml", true);
    }

    @Test
    @Ignore("test file not found in resources")
    public void getCreateFictionalApplicationResponse_TC_FAPP2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateFictionalApplication(RESPONSE_FOLDER +"EMOHMDF102CreateFictionalApplicationResponse_TC_FAPP2.xml", true);
    }

    @Test
    @Ignore("test file not found in resources")
    public void getCreateFictionalApplicationResponse_TC_FAPP3() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateFictionalApplication(RESPONSE_FOLDER +"EMOHMDF102CreateFictionalApplicationResponse_TC_FAPP3.xml", true);
    }

    @Test
    @Ignore("test file not found in resources")
    public void getCreateFictionalApplicationResponse_TC_FAPP4() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_CreateFictionalApplication(RESPONSE_FOLDER +"EMOHMDF102CreateFictionalApplicationResponse_TC_FAPP3.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES1.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES2.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES3() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES3.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES4() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES4.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES5() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES5.xml", true);
    }

    @Test
    public void getPushDecision_TC_PDES6() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionRequest_TC_PDES6.xml", false);
    }

    @Test
    public void getPushDecision_TC_PDES7() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushDecision(RESPONSE_FOLDER +"EMOHMDF106PushDecisionResponse_TC_PDES7.xml", true);
    }

    @Test
    public void getPushApplicationView_TC_PVIEW() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_PushApplicationView(RESPONSE_FOLDER +"EMOHMDF107PushApplicationViewRequest_TC_PVIEW.xml", true);
    }

    @Test
    public void getListInvoiceFileAccepted() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ListInvoiceFileAccepted(RESPONSE_FOLDER +"921000_TC02.txt", true);
    }

    @Test
    public void getListInvoiceAccepted1() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ListInvoiceAccepted1(RESPONSE_FOLDER +"920098_TC02.txt", true);
    }

    @Test
    public void getListInvoiceAccepted2() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ListInvoiceAccepted2(RESPONSE_FOLDER +"920900_TC02.txt", true);
    }

    @Test
    public void getListInvoiceRefused() {
        Assert.fail("not testable at the time of release 3.16.0-beta-3");
    }

    @Test
    public void getListInvoiceFileRefused() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_ListInvoiceFileRefused(RESPONSE_FOLDER +"920999_TC01.txt", true);
    }

    @Test
    public void getDetermineInsurability_TC01() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_DetermineInsurability(RESPONSE_FOLDER +"WZCMHDF001DetermineInsurabilityResponse_TC_1.xml", true);
    }

    @Test
    public void getDetermineInsurability_TC02() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_DetermineInsurability(RESPONSE_FOLDER +"WZCMHDF001DetermineInsurabilityResponse_TC_2.xml", true);
    }

    @Test
    public void getDetermineInsurability_TC03() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_DetermineInsurability(RESPONSE_FOLDER +"WZCMHDF001DetermineInsurabilityResponse_TC_3.xml", true);
    }

    @Test
    public void getDetermineInsurability_TC04() throws Exception {
        VsbNetGenericAsyncMethod.do_GET_DetermineInsurability(RESPONSE_FOLDER +"WZCMHDF001DetermineInsurabilityResponse_TC_4.xml", true);
    }
}
